## CHANGELOG

### 0.4.0 - 2019-11-07

 - Skip errors and count them

### 0.3.0 - 2019-11-07

 - Add support for multiple workers

### 0.2.1 - 2019-11-07

 - Fix requirements

### 0.2.0 - 2019-11-07

 - Add support for distribution calls

### 0.1.0 - 2019-11-04

 - Create first version of the application
